@@ -16,12 +16,10 @@
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
-#include <QPixmap>
 
 #include <X11/Xutil.h>
 #include <X11/extensions/dpms.h>
 
-#include <QX11Info>
 #include <X11/Xlib.h>
 #include <X11/extensions/Xrender.h>
 
