@@ -1,6 +1,7 @@
 /*
-   Copyright (C) 2005-2006,2009 Tom Albers <toma@kde.org>
+   Copyright (C) 2005-2006,2009-2010 Tom Albers <toma@kde.org>
    Copyright (C) 2006 Bram Schoenmakers <bramschoenmakers@kde.nl>
+   Copyright (C) 2010 Juan Luis Baptiste <juan.baptiste@gmail.com>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -94,60 +95,11 @@ RSIObject::~RSIObject()
     delete RSIGlobals::instance();
 }
 
-QPixmap RSIObject::takeScreenshot( RSIDock* tray )
-{
-    // taken from Akregator http://lxr.kde.org/source/KDE/kdepim/akregator/src/trayicon.cpp#70
-    //     Copyright (C) 2004 Stanislav Karchebny <Stanislav.Karchebny@kdemail.net>
-
-    const QRect rect = tray->geometry();
-    const QPoint g = rect.topLeft();
-    int desktopWidth  = kapp->desktop()->width();
-    int desktopHeight = kapp->desktop()->height();
-    int tw = rect.width();
-    int th = rect.height();
-    int w = desktopWidth / 4;
-    int h = desktopHeight / 9;
-    int x = g.x() + tw/2 - w/2; // Center the rectange in the systray icon
-    int y = g.y() + th/2 - h/2;
-    if ( x < 0 )
-        x = 0; // Move the rectangle to stay in the desktop limits
-    if ( y < 0 )
-        y = 0;
-    if ( x + w > desktopWidth )
-        x = desktopWidth - w;
-    if ( y + h > desktopHeight )
-        y = desktopHeight - h;
-
-    // Grab the desktop and draw a circle around the icon:
-    QPixmap shot = QPixmap::grabWindow( QApplication::desktop()->winId(), x, y, w, h );
-    QPainter painter( &shot );
-    painter.setRenderHint( QPainter::Antialiasing );
-    const int MARGINS = 6;
-    const int WIDTH   = 3;
-    int ax = g.x() - x - MARGINS -1;
-    int ay = g.y() - y - MARGINS -1;
-    painter.setPen( QPen( Qt::red/*KApplication::palette().active().highlight()*/, WIDTH ) );
-    painter.drawArc( ax, ay, tw + 2*MARGINS, th + 2*MARGINS, 0, 16*360 );
-    painter.end();
-
-    // Paint the border
-    const int BORDER = 1;
-    QPixmap finalShot( w + 2*BORDER, h + 2*BORDER );
-    finalShot.fill( KApplication::palette().color( QPalette::Foreground ) );
-    painter.begin( &finalShot );
-    painter.drawPixmap( BORDER, BORDER, shot );
-    painter.end();
-    return finalShot;
-    // end taken....
-}
-
 void RSIObject::slotWelcome()
 {
     if ( KMessageBox::shouldBeShownContinue( "dont_show_welcome_again_for_001" ) ) {
-        QString tempfile = takeScreenshotOfTrayIcon();
         KMessageBox::information( 0, i18n( "<p>Welcome to RSIBreak</p>\n<p>"
-                                           "In your tray you can now see RSIBreak:</p>\n" )
-                                  + "<p><center><img source=\"" + tempfile + "\"></center></p>\n"
+                                           "In your tray you can now see RSIBreak.</p>\n" )
                                   + i18n( "<p>When you right-click on that you will see a menu, from which "
                                           "you can go to the configuration for example.</p>\n<p>When you want to "
                                           "know when the next break is, hover over the icon.</p>\n<p>Use RSIBreak "
@@ -155,34 +107,6 @@ void RSIObject::slotWelcome()
     }
 }
 
-void RSIObject::showWhereIAm()
-{
-    QString tempfile = takeScreenshotOfTrayIcon();
-    KMessageBox::information( 0,
-                              i18n( "<p>RSIBreak is already running</p><p>It is located here:</p>" )
-                              + "<p><center><img source=\"" + tempfile + "\"></center></p><p>",
-                              i18n( "Already Running" ) );
-}
-
-QString RSIObject::takeScreenshotOfTrayIcon()
-{
-    // Process the events else the icon will not be there and the screenie will fail!
-    kapp->processEvents();
-
-    //TODO: find the tray window.
-    QPixmap screenshot = takeScreenshot( m_tray );
-
-    QString filename;
-    KTemporaryFile* tmpfile = new KTemporaryFile;
-    tmpfile->setAutoRemove( false );
-    if ( tmpfile->open() ) {
-        filename = tmpfile->fileName();
-        screenshot.save( tmpfile, "png" );
-        tmpfile->close();
-    }
-    return filename;
-}
-
 void RSIObject::minimize()
 {
     m_effect->deactivate();
@@ -197,6 +121,7 @@ void RSIObject::slotLock()
 {
     kDebug();
     m_effect->deactivate();
+    m_timer->slotRestart();
 
     QDBusInterface lock( "org.freedesktop.ScreenSaver", "/ScreenSaver",
                          "org.freedesktop.ScreenSaver" );
@@ -206,7 +131,7 @@ void RSIObject::slotLock()
 void RSIObject::setCounters( int timeleft )
 {
     if ( timeleft > 0 ) {
-        m_effect->setLabel( KGlobal::locale()->prettyFormatDuration( timeleft * 1000) );
+        m_effect->setLabel( KGlobal::locale()->prettyFormatDuration( timeleft * 1000 ) );
     } else if ( m_timer->isSuspended() ) {
         m_effect->setLabel( i18n( "Suspended" ) );
     } else {
@@ -311,10 +236,10 @@ void RSIObject::startTimer( bool idle )
     connect( m_tray, SIGNAL( dialogEntered() ), m_timer, SLOT( slotStop() ) );
     connect( m_tray, SIGNAL( dialogLeft() ), m_timer, SLOT( slotStart() ) );
     connect( m_tray, SIGNAL( breakRequest() ), m_timer, SLOT( slotRequestBreak() ) );
-    connect( m_tray, SIGNAL( debugRequest() ), m_timer, SLOT( slotRequestDebug() ) );
     connect( m_tray, SIGNAL( suspend( bool ) ), m_timer, SLOT( slotSuspended( bool ) ) );
 
     connect( m_relaxpopup, SIGNAL( skip() ), m_timer, SLOT( skipBreak() ) );
+    connect( m_relaxpopup, SIGNAL( postpone() ), m_timer, SLOT( postponeBreak() ) );
 
     first = false;
 }
@@ -326,14 +251,18 @@ void RSIObject::readConfig()
 
     m_relaxpopup->setSkipButtonHidden(
         config.readEntry( "HideMinimizeButton", false ) );
+    m_relaxpopup->setLockButtonHidden(
+        config.readEntry( "HideLockButton", false ) );
+    m_relaxpopup->setPostponeButtonHidden(
+        config.readEntry( "HidePostponeButton", false ) );
 
     m_usePlasma = config.readEntry( "UsePlasma", false );
     m_usePlasmaRO = config.readEntry( "UsePlasmaReadOnly", false );
 
     m_useImages = config.readEntry( "ShowImages", false );
     int slideInterval = config.readEntry( "SlideInterval", 10 );
-    bool recursive =
-        config.readEntry( "SearchRecursiveCheck", false );
+    bool recursive =  config.readEntry( "SearchRecursiveCheck", false );
+    bool showSmallImages = config.readEntry( "ShowSmallImagesCheck", true );
     QString path = config.readEntry( "ImageFolder" );
 
     bool timertype = config.readEntry( "UseNoIdleTimer", false );
@@ -345,12 +274,12 @@ void RSIObject::readConfig()
     switch ( effect ) {
     case Plasma: {
         m_effect = new PlasmaEffect( 0 );
-        m_effect ->setReadOnly( m_usePlasmaRO );
+        m_effect->setReadOnly( m_usePlasmaRO );
         break;
     }
     case SlideShow: {
         SlideEffect* slide = new SlideEffect( 0 );
-        slide->reset( path, recursive, slideInterval );
+        slide->reset( path, recursive, showSmallImages, slideInterval );
         if ( slide->hasImages() )
             m_effect = slide;
         else {
@@ -375,8 +304,11 @@ void RSIObject::readConfig()
     }
     connect( m_effect, SIGNAL( skip() ), m_timer, SLOT( skipBreak() ) );
     connect( m_effect, SIGNAL( lock() ), this, SLOT( slotLock() ) );
+    connect( m_effect, SIGNAL( postpone()),  m_timer, SLOT( postponeBreak() ) );
 
     m_effect->showMinimize( !config.readEntry( "HideMinimizeButton", false ) );
+    m_effect->showLock( !config.readEntry( "HideLockButton", false ) );
+    m_effect->showPostpone( !config.readEntry( "HidePostponeButton", false ) );
     m_effect->disableShortcut( config.readEntry( "DisableAccel", false ) );
 }
 
