@@ -1,5 +1,5 @@
 /* ============================================================
- * Copyright 2005-2007 by Tom Albers <toma@kde.org>
+ * Copyright 2005-2007,2010 by Tom Albers <toma@kde.org>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -34,6 +34,7 @@
 #include <KApplication>
 #include <KFileDialog>
 #include <KLineEdit>
+#include <KNumInput>
 #include <KVBox>
 #include <KWindowSystem>
 #include <kkeysequencewidget.h>
@@ -51,14 +52,19 @@ public:
     KLineEdit*        imageFolderEdit;
     QCheckBox*        searchRecursiveCheck;
     QCheckBox*        hideMinimizeButton;
+    QCheckBox*        hideLockButton;
+    QCheckBox*        hidePostponeButton;    
     QCheckBox*        disableAccel;
     QPushButton*      changePathButton;
+    KIntNumInput*     slideInterval;
+    KIntNumInput*     popupDuration;
     QCheckBox*        usePopup;
     QCheckBox*        useFlash;
     QLabel*           useFlashLabel;
     QCheckBox*        readOnlyPlasma;
     KComboBox*        effectBox;
     QSlider*          graySlider;
+    QCheckBox* showSmallImagesCheck;
 };
 
 SetupMaximized::SetupMaximized( QWidget* parent )
@@ -70,15 +76,15 @@ SetupMaximized::SetupMaximized( QWidget* parent )
 
     // Counterbox and skipbox next to eachother
 
-    QLabel* effectLabel = new QLabel( i18n( "Chose the effect you want to during breaks" ) );
+    QLabel* effectLabel = new QLabel( i18n( "Choose the effect you want during breaks" ) );
     d->effectBox = new KComboBox( this );
     if ( KWindowSystem::compositingActive() )
-        d->effectBox->addItem( i18n("Simple Gray Effect"), QVariant( RSIObject::SimpleGray ) );
+        d->effectBox->addItem( i18n( "Simple Gray Effect" ), QVariant( RSIObject::SimpleGray ) );
     else
-        d->effectBox->addItem( i18n("Complete Black Effect"), QVariant( RSIObject::SimpleGray ) );
-    d->effectBox->addItem( i18n("Show Plasma Dashboard"), QVariant( RSIObject::Plasma ) );
-    d->effectBox->addItem( i18n("Show Slide Show of Images"), QVariant( RSIObject::SlideShow ) );
-    d->effectBox->addItem( i18n("Show a Passive Popup"), QVariant( RSIObject::Popup ) );
+        d->effectBox->addItem( i18n( "Complete Black Effect" ), QVariant( RSIObject::SimpleGray ) );
+    d->effectBox->addItem( i18n( "Show Plasma Dashboard" ), QVariant( RSIObject::Plasma ) );
+    d->effectBox->addItem( i18n( "Show Slide Show of Images" ), QVariant( RSIObject::SlideShow ) );
+    d->effectBox->addItem( i18n( "Show a Passive Popup" ), QVariant( RSIObject::Popup ) );
     connect( d->effectBox, SIGNAL( currentIndexChanged( int ) ),
              SLOT( slotEffectChanged( int ) ) );
 
@@ -90,12 +96,21 @@ SetupMaximized::SetupMaximized( QWidget* parent )
     d->hideMinimizeButton->setWhatsThis( i18n( "Check this option to disable and "
                                          "hide the skip button. This way you can prevent skipping the break." ) );
 
+    d->hideLockButton = new QCheckBox( i18n( "&Hide lock button" ), this );
+    d->hideLockButton->setWhatsThis( i18n( "Check this option to disable and "
+                                           "hide the lock button. This way you can prevent pressing the wrong button." ) );
+    d->hidePostponeButton = new QCheckBox( i18n( "&Hide postpone button" ), this );
+    d->hidePostponeButton->setWhatsThis( i18n( "Check this option to disable and "
+                                           "hide the postpone break button. This way you can prevent pressing the wrong button." ) );
+    
     d->disableAccel = new QCheckBox( i18n( "&Disable shortcut" ), this );
     d->disableAccel->setWhatsThis( i18n( "Check this option to disable the skip "
                                          "shortcut. This way you can prevent skipping the break." ) );
 
     QVBoxLayout *vbox1 = new QVBoxLayout( skipBox );
     vbox1->addWidget( d->hideMinimizeButton );
+    vbox1->addWidget( d->hideLockButton );
+    vbox1->addWidget( d->hidePostponeButton );
     vbox1->addWidget( d->disableAccel );
     vbox1->addStretch( 1 );
     skipBox->setLayout( vbox1 );
@@ -143,6 +158,18 @@ SetupMaximized::SetupMaximized( QWidget* parent )
                                            imageFolderBox );
     d->searchRecursiveCheck = new QCheckBox( i18n( "Search path recursively" ),
             this );
+    d->showSmallImagesCheck = new QCheckBox( i18n( "Show small images" ),
+            this );
+
+    KHBox *m5 = new KHBox( this );
+    QLabel *l5 = new QLabel( i18n( "Change images every:" ) + ' ', m5 );
+    l5->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
+    l5->setWhatsThis( i18n( "Here you can set how long one image should be "
+                            "shown before it is replaced by the next one." ) );
+    d->slideInterval = new KIntNumInput( m5 );
+    d->slideInterval->setRange( 3, 1000, 1 );
+    d->slideInterval->setSliderEnabled( false );
+    d->slideInterval->setSuffix( ki18np( " second", " seconds" ) );
 
     connect( d->changePathButton, SIGNAL( clicked() ),
              this, SLOT( slotFolderPicker() ) );
@@ -152,6 +179,8 @@ SetupMaximized::SetupMaximized( QWidget* parent )
     QVBoxLayout *vbox2 = new QVBoxLayout( d->slideshowBox );
     vbox2->addWidget( imageFolderBox );
     vbox2->addWidget( d->searchRecursiveCheck );
+    vbox2->addWidget( d->showSmallImagesCheck );
+    vbox2->addWidget( m5 );
     d->slideshowBox->setLayout( vbox2 );
 
     //---------------- Popup setup
@@ -160,7 +189,7 @@ SetupMaximized::SetupMaximized( QWidget* parent )
     popupBox->setTitle( i18n( "Popup" ) );
 
     QLabel *label = new QLabel( i18n( "RSIBreak can show a popup near the "
-                                      "systray instead of replacing your whole screen with a picture." ), this );
+                                      "systray before replacing your whole screen with the effect chosen." ), this );
     label->setWordWrap( true );
 
     d->usePopup = new QCheckBox( i18n( "&Use the popup" ), this );
@@ -170,6 +199,16 @@ SetupMaximized::SetupMaximized( QWidget* parent )
                                      "zero, so you know how long this break will be." ) );
     label->setBuddy( d->usePopup );
 
+    KHBox *m6 = new KHBox( this );
+    QLabel *l6 = new QLabel( i18n( "Show popup for a maximum of:" ) + ' ', m6 );
+    l6->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
+    l6->setWhatsThis( i18n( "Here you can set how long the popup will be shown "
+                            "before the effect will kick in." ) );
+    d->popupDuration = new KIntNumInput( m6 );
+    d->popupDuration->setRange( 3, 1000, 1 );
+    d->popupDuration->setSliderEnabled( false );
+    d->popupDuration->setSuffix( ki18np( " second", " seconds" ) );
+
     d->useFlashLabel = new QLabel( '\n' + i18n( "The popup can flash when it "
                                    "detects that you are still active." ), this );
     d->useFlashLabel->setWordWrap( true );
@@ -182,6 +221,7 @@ SetupMaximized::SetupMaximized( QWidget* parent )
     QVBoxLayout *vbox3 = new QVBoxLayout( popupBox );
     vbox3->addWidget( label );
     vbox3->addWidget( d->usePopup );
+    vbox3->addWidget( m6 );
     vbox3->addWidget( d->useFlashLabel );
     vbox3->addWidget( d->useFlash );
     vbox3->addStretch( 1 );
@@ -262,10 +302,19 @@ void SetupMaximized::applySettings()
 {
     KConfigGroup config = KGlobal::config()->group( "General Settings" );
     config.writeEntry( "ImageFolder", d->imageFolderEdit->text() );
+    config.writeEntry( "SlideInterval", d->slideInterval->value() );
+    config.writeEntry( "Patience", d->popupDuration->value() );
+
     config.writeEntry( "HideMinimizeButton",
                        d->hideMinimizeButton->isChecked() );
+    config.writeEntry( "HideLockButton",
+                       d->hideLockButton->isChecked() );
+    config.writeEntry( "HidePostponeButton",
+                       d->hidePostponeButton->isChecked() );    
     config.writeEntry( "SearchRecursiveCheck",
                        d->searchRecursiveCheck->isChecked() );
+    config.writeEntry( "ShowSmallImagesCheck",
+                       d->showSmallImagesCheck->isChecked() );
     config.writeEntry( "Effect",
                        d->effectBox->itemData( d->effectBox->currentIndex() ) );
 
@@ -290,8 +339,15 @@ void SetupMaximized::readSettings()
 
     KConfigGroup config = KGlobal::config()->group( "General Settings" );
     d->imageFolderEdit->setText( config.readEntry( "ImageFolder", dir ) );
+    d->slideInterval->setValue( config.readEntry( "SlideInterval", 10 ) );
+    d->popupDuration->setValue( config.readEntry( "Patience", 30 ) );
+
     d->hideMinimizeButton->setChecked(
         config.readEntry( "HideMinimizeButton", false ) );
+    d->hideLockButton->setChecked(
+        config.readEntry( "HideLockButton", false ) );
+    d->hidePostponeButton->setChecked(
+        config.readEntry( "HidePostponeButton", false ) );
 
     const int effect = d->effectBox->findData( QVariant(
                            config.readEntry( "Effect", 0 ) ) );
@@ -300,6 +356,8 @@ void SetupMaximized::readSettings()
 
     d->searchRecursiveCheck->setChecked(
         config.readEntry( "SearchRecursiveCheck", false ) );
+    d->showSmallImagesCheck->setChecked(
+        config.readEntry( "ShowSmallImagesCheck", true ) );
     d->disableAccel->setChecked( config.readEntry( "DisableAccel", false ) );
     d->readOnlyPlasma->setChecked(
         config.readEntry( "UsePlasmaReadOnly", true ) );
